@@ -1,14 +1,13 @@
-import numpy as np
-
+from autoconf import conf
 import autoarray as aa
-import autofit as af
-from autoastro.galaxy import galaxy as g
+import numpy as np
+from autogalaxy.galaxy import galaxy as g
 from autolens.pipeline.phase import dataset
 
 
 class Result(dataset.Result):
     @property
-    def most_likely_fit(self):
+    def max_log_likelihood_fit(self):
 
         hyper_image_sky = self.analysis.hyper_image_sky_for_instance(
             instance=self.instance
@@ -19,23 +18,23 @@ class Result(dataset.Result):
         )
 
         return self.analysis.masked_imaging_fit_for_tracer(
-            tracer=self.most_likely_tracer,
+            tracer=self.max_log_likelihood_tracer,
             hyper_image_sky=hyper_image_sky,
             hyper_background_noise=hyper_background_noise,
         )
 
     @property
     def unmasked_model_image(self):
-        return self.most_likely_fit.unmasked_blurred_profile_image
+        return self.max_log_likelihood_fit.unmasked_blurred_image
 
     @property
     def unmasked_model_image_of_planes(self):
-        return self.most_likely_fit.unmasked_blurred_profile_image_of_planes
+        return self.max_log_likelihood_fit.unmasked_blurred_image_of_planes
 
     @property
     def unmasked_model_image_of_planes_and_galaxies(self):
-        fit = self.most_likely_fit
-        return fit.unmasked_blurred_profile_image_of_planes_and_galaxies
+        fit = self.max_log_likelihood_fit
+        return fit.unmasked_blurred_image_of_planes_and_galaxies
 
     def image_for_galaxy(self, galaxy: g.Galaxy) -> np.ndarray:
         """
@@ -49,7 +48,7 @@ class Result(dataset.Result):
         ndarray or None
             A numpy arrays giving the model image of that galaxy
         """
-        return self.most_likely_fit.galaxy_model_image_dict[galaxy]
+        return self.max_log_likelihood_fit.galaxy_model_image_dict[galaxy]
 
     @property
     def image_galaxy_dict(self) -> {str: g.Galaxy}:
@@ -67,7 +66,7 @@ class Result(dataset.Result):
         A dictionary associating 1D hyper_galaxies galaxy images with their names.
         """
 
-        hyper_minimum_percent = af.conf.instance.general.get(
+        hyper_minimum_percent = conf.instance.general.get(
             "hyper", "hyper_minimum_percent", float
         )
 
@@ -94,3 +93,9 @@ class Result(dataset.Result):
             hyper_model_image += self.hyper_galaxy_image_path_dict[path]
 
         return hyper_model_image
+
+    @property
+    def stochastic_log_evidences(self):
+        return self.analysis.stochastic_log_evidences_for_instance(
+            instance=self.instance
+        )
